@@ -38,8 +38,10 @@
 #include <attr/libattr.h>
 #endif				/* WITH_ATTR */
 #include "shadowlog.h"
-#include "string/sprintf/xasprintf.h"
+#include "string/sprintf/aprintf.h"
+#include "string/sprintf/xaprintf.h"
 #include "string/strcmp/streq.h"
+#include "string/strcmp/strprefix.h"
 
 
 static /*@null@*/const char *src_orig;
@@ -232,7 +234,7 @@ static /*@exposed@*/ /*@null@*/struct link_name *check_link (const char *name, c
 	lp->ln_dev = sb->st_dev;
 	lp->ln_ino = sb->st_ino;
 	lp->ln_count = sb->st_nlink;
-	xasprintf(&lp->ln_name, "%s%s", dst_orig, name + strlen(src_orig));
+	lp->ln_name = xaprintf("%s%s", dst_orig, name + strlen(src_orig));
 	lp->ln_next = links;
 	links = lp;
 
@@ -321,13 +323,13 @@ static int copy_tree_impl (const struct path_info *src, const struct path_info *
 			continue;
 		}
 
-		if (asprintf(&src_name, "%s/%s", src->full_path, ent->d_name) == -1)
-		{
+		src_name = aprintf("%s/%s", src->full_path, ent->d_name);
+		if (src_name == NULL) {
 			err = -1;
 			continue;
 		}
-		if (asprintf(&dst_name, "%s/%s", dst->full_path, ent->d_name) == -1)
-		{
+		dst_name = aprintf("%s/%s", dst->full_path, ent->d_name);
+		if (dst_name == NULL) {
 			err = -1;
 			goto skip;
 		}
@@ -576,10 +578,10 @@ static int copy_symlink (const struct path_info *src, const struct path_info *ds
 	 * create a link to the corresponding entry in the dst_orig
 	 * directory.
 	 */
-	if (strncmp(oldlink, src_orig, strlen(src_orig)) == 0) {
+	if (strprefix(oldlink, src_orig)) {
 		char  *dummy;
 
-		xasprintf(&dummy, "%s%s", dst_orig, oldlink + strlen(src_orig));
+		dummy = xaprintf("%s%s", dst_orig, oldlink + strlen(src_orig));
 		free(oldlink);
 		oldlink = dummy;
 	}
