@@ -20,7 +20,9 @@
 #include "port.h"
 #include "prototypes.h"
 #include "string/strcmp/streq.h"
+#include "string/strcmp/strprefix.h"
 #include "string/strtok/stpsep.h"
+#include "string/strtok/strsep2ls.h"
 
 
 static FILE *ports;
@@ -50,7 +52,7 @@ static int portcmp (const char *pattern, const char *port)
 	if (streq(orig, "SU"))
 		return 1;
 
-	return (*pattern == '*') ? 0 : 1;
+	return !strprefix(pattern, "*");
 }
 
 /*
@@ -101,7 +103,8 @@ getportent(void)
 	int   dtime;
 	int   i, j;
 	int   saveerr;
-	char  *cp, *field;
+	char  *cp;
+	char  *fields[3];
 
 	static char            buf[BUFSIZ];
 	static char            *ttys[PORT_TTY + 1];
@@ -140,12 +143,13 @@ next:
 		errno = saveerr;
 		return NULL;
 	}
-	if ('#' == buf[0])
+	if (strprefix(buf, "#"))
 		goto next;
 
 	stpsep(buf, "\n");
 
-	field = buf;
+	if (STRSEP2ARR(buf, ":", fields) == -1)
+		goto next;
 
 	/*
 	 * Get the name of the TTY device.  It is the first colon
@@ -153,19 +157,8 @@ next:
 	 * leading "/dev".  The entry '*' is used to specify all
 	 * TTY devices.
 	 */
-
-	cp = strsep(&field, ":");
-	if (field == NULL)
-		goto next;
-
 	port.pt_names = ttys;
-	for (j = 0; j < PORT_TTY; j++) {
-		port.pt_names[j] = strsep(&cp, ",");
-		if (cp == NULL)
-			break;
-	}
-	port.pt_names[j] = NULL;
-	if (cp != NULL)
+	if (STRSEP2LS(fields[0], ",", ttys) == -1)
 		goto next;
 
 	/*
@@ -174,19 +167,8 @@ next:
 	 * names.  The entry '*' is used to specify all usernames.
 	 * The last entry in the list is a NULL pointer.
 	 */
-
-	cp = strsep(&field, ":");
-	if (field == NULL)
-		goto next;
-
 	port.pt_users = users;
-	for (j = 0; j < PORT_IDS; j++) {
-		port.pt_users[j] = strsep(&cp, ",");
-		if (cp == NULL)
-			break;
-	}
-	port.pt_users[j] = NULL;
-	if (cp != NULL)
+	if (STRSEP2LS(fields[1], ",", users) == -1)
 		goto next;
 
 	/*
@@ -202,7 +184,7 @@ next:
 	 * the starting time.  Days are presumed to wrap at 0000.
 	 */
 
-	cp = field;
+	cp = fields[2];
 
 	if (streq(cp, "")) {
 		port.pt_times = NULL;
