@@ -10,8 +10,8 @@
 
 #include <search.h>
 
-#include "must_be.h"
 #include "search/cmp/cmp.h"
+#include "typetraits.h"
 
 #include <assert.h>
 
