@@ -16,6 +16,8 @@
 #include <stdio.h>
 #include <sys/types.h>
 #include <getopt.h>
+
+#include "attr.h"
 #include "defines.h"
 #include "prototypes.h"
 /*@-exitarg@*/
@@ -27,14 +29,14 @@ static const char Prog[] = "expiry";
 static bool cflg = false;
 
 /* local function prototypes */
-static void catch_signals (unused int sig);
+static void catch_signals (MAYBE_UNUSED int sig);
 NORETURN static void usage (int status);
 static void process_flags (int argc, char **argv);
 
 /*
  * catch_signals - signal catcher
  */
-static void catch_signals (unused int sig)
+static void catch_signals (MAYBE_UNUSED int sig)
 {
 	_exit (10);
 }
