@@ -25,6 +25,7 @@
 #include "shadowlog.h"
 #include "sssd.h"
 #include "string/strcmp/streq.h"
+#include "string/strcmp/strprefix.h"
 
 #ifdef SHADOWGRP
 #include "sgroupio.h"
@@ -470,7 +471,7 @@ static void check_grp_file (bool *errors, bool *changed)
 		 * Skip all NIS entries.
 		 */
 
-		if ((gre->line[0] == '+') || (gre->line[0] == '-')) {
+		if (strprefix(gre->line, "+") || strprefix(gre->line, "-")) {
 			continue;
 		}
 
