@@ -34,7 +34,7 @@
 
 #include "alloc/reallocf.h"
 #include "atoi/getnum.h"
-#include "atoi/str2i/str2s.h"
+#include "atoi/str2i.h"
 #ifdef ACCT_TOOLS_SETUID
 #ifdef USE_PAM
 #include "pam_defs.h"
@@ -58,6 +58,7 @@
 #include "string/strcmp/streq.h"
 #include "string/strdup/xstrdup.h"
 #include "string/strtok/stpsep.h"
+#include "string/strtok/strsep2arr.h"
 
 
 /*
@@ -1059,9 +1060,7 @@ static bool want_subgids(void)
 int main (int argc, char **argv)
 {
 	char buf[BUFSIZ];
-	char *fields[8];
-	int nfields;
-	char *cp;
+	char *fields[7];
 	const struct passwd *pw;
 	struct passwd newpw;
 	intmax_t line = 0;
@@ -1119,17 +1118,7 @@ int main (int argc, char **argv)
 			fail_exit (EXIT_FAILURE);
 		}
 
-		/*
-		 * Break the string into fields and screw around with them.
-		 * There MUST be 7 colon separated fields, although the
-		 * values aren't that particular.
-		 */
-		for (cp = buf, nfields = 0; nfields < 7; nfields++) {
-			fields[nfields] = strsep(&cp, ":");
-			if (cp == NULL)
-				break;
-		}
-		if (nfields != 6) {
+		if (STRSEP2ARR(buf, ":", fields) == -1) {
 			fprintf (stderr, _("%s: line %jd: invalid line\n"),
 			         Prog, line);
 			fail_exit (EXIT_FAILURE);
