@@ -33,8 +33,9 @@
 #include "shadowlog.h"
 #include "sssd.h"
 #include "string/memset/memzero.h"
-#include "string/sprintf/xasprintf.h"
+#include "string/sprintf/xaprintf.h"
 #include "string/strcmp/streq.h"
+#include "string/strcmp/strprefix.h"
 #include "string/strcpy/strtcpy.h"
 #include "string/strdup/xstrdup.h"
 #include "time/day_to_str.h"
@@ -51,6 +52,7 @@
 #define E_MISSING	4	/* unexpected failure, passwd file missing */
 #define E_PWDBUSY	5	/* passwd file busy, try again later */
 #define E_BAD_ARG	6	/* invalid argument to option */
+#define E_PAM_ERR	10	/* PAM returned an error */
 /*
  * Global variables
  */
@@ -401,7 +403,7 @@ static void check_password (const struct passwd *pw, const struct spwd *sp)
 	 * changed. Passwords which have been inactive too long cannot be
 	 * changed.
 	 */
-	if (   (sp->sp_pwdp[0] == '!')
+	if (   strprefix(sp->sp_pwdp, "!")
 	    || (exp_status > 1)
 	    || (   (sp->sp_max >= 0)
 	        && (sp->sp_min > sp->sp_max))) {
@@ -438,7 +440,7 @@ static void check_password (const struct passwd *pw, const struct spwd *sp)
 
 static /*@observer@*/const char *pw_status (const char *pass)
 {
-	if (*pass == '*' || *pass == '!') {
+	if (strprefix(pass, "*") || strprefix(pass, "!")) {
 		return "L";
 	}
 	if (streq(pass, "")) {
@@ -519,7 +521,7 @@ static char *update_crypt_pw (char *cp)
 	if (dflg)
 		strcpy(cp, "");
 
-	if (uflg && *cp == '!') {
+	if (uflg && strprefix(cp, "!")) {
 		if (cp[1] == '\0') {
 			(void) fprintf (stderr,
 			                _("%s: unlocking the password would result in a passwordless account.\n"
@@ -534,7 +536,7 @@ static char *update_crypt_pw (char *cp)
 	if (lflg && *cp != '!') {
 		char  *newpw;
 
-		xasprintf(&newpw, "!%s", cp);
+		newpw = xaprintf("!%s", cp);
 		if (!use_pam)
 		{
 			if (do_update_pwd) {
