@@ -60,8 +60,9 @@
 #include "prototypes.h"
 #include "shadowlog.h"
 #include "string/sprintf/snprintf.h"
-#include "string/sprintf/xasprintf.h"
+#include "string/sprintf/xaprintf.h"
 #include "string/strcmp/streq.h"
+#include "string/strcmp/strprefix.h"
 #include "string/strcpy/strtcpy.h"
 #include "string/strdup/xstrdup.h"
 
@@ -714,7 +715,7 @@ static /*@only@*/struct passwd * do_check_perms (void)
 	 * the shell specified in /etc/passwd (not the one specified with
 	 * --shell, which will be the one executed in the chroot later).
 	 */
-	if ('*' == pw->pw_shell[0]) {	/* subsystem root required */
+	if (strprefix(pw->pw_shell, "*")) {  /* subsystem root required */
 		subsystem (pw);	/* change to the subsystem root */
 		endpwent ();		/* close the old password databases */
 		endspent ();
@@ -915,7 +916,7 @@ static void set_environment (struct passwd *pw)
 #ifndef USE_PAM
 		cp = getdef_str ("ENV_TZ");
 		if (NULL != cp) {
-			addenv (('/' == *cp) ? tz (cp) : cp, NULL);
+			addenv(strprefix(cp, "/") ? tz(cp) : cp, NULL);
 		}
 
 		/*
@@ -1204,15 +1205,12 @@ int main (int argc, char **argv)
 	 * case they will be provided to the new user's shell as arguments.
 	 */
 	if (fakelogin) {
-		char  *arg0;
-
 		cp = getdef_str ("SU_NAME");
 		if (NULL == cp) {
 			cp = Basename (shellstr);
 		}
 
-		xasprintf(&arg0, "-%s", cp);
-		cp = arg0;
+		cp = xaprintf("-%s", cp);
 	} else {
 		cp = Basename (shellstr);
 	}
