@@ -20,6 +20,7 @@
 #include "defines.h"
 #include "prototypes.h"
 #include "string/strcmp/streq.h"
+#include "string/strcmp/strprefix.h"
 #include "string/strspn/stpspn.h"
 #include "string/strspn/stprspn.h"
 #include "string/strtok/stpsep.h"
@@ -87,7 +88,7 @@ check_su_auth(const char *actual_id, const char *wanted_id, bool su_to_root)
 		stpcpy(stprspn(temp, " \t"), "");
 
 		p = stpspn(temp, " \t");
-		if (*p == '#' || streq(p, ""))
+		if (strprefix(p, "#") || streq(p, ""))
 			continue;
 
 		to_users = strsep(&p, ":");
