@@ -51,8 +51,10 @@
 #include "subordinateio.h"
 #endif				/* ENABLE_SUBIDS */
 #include "shadowlog.h"
-#include "string/sprintf/xasprintf.h"
+#include "string/sprintf/aprintf.h"
+#include "string/sprintf/xaprintf.h"
 #include "string/strcmp/streq.h"
+#include "string/strcmp/strprefix.h"
 #include "string/strdup/xstrdup.h"
 
 
@@ -701,7 +703,7 @@ static void user_cancel (const char *user)
 #ifdef EXTRA_CHECK_HOME_DIR
 static bool path_prefix (const char *s1, const char *s2)
 {
-	return (   (strncmp (s2, s1, strlen (s1)) == 0)
+	return (   strprefix(s2, s1)
 	        && (   ('\0' == s2[strlen (s1)])
 	            || ('/'  == s2[strlen (s1)])));
 }
@@ -749,9 +751,9 @@ static bool remove_mailbox (void)
 	}
 
 	if (prefix[0]) {
-		xasprintf(&mailfile, "%s/%s/%s", prefix, maildir, user_name);
+		mailfile = xaprintf("%s/%s/%s", prefix, maildir, user_name);
 	} else {
-		xasprintf(&mailfile, "%s/%s", maildir, user_name);
+		mailfile = xaprintf("%s/%s", maildir, user_name);
 	}
 
 	if (access (mailfile, F_OK) != 0) {
@@ -855,7 +857,8 @@ static int remove_tcbdir (const char *user_name, uid_t user_id)
 		return 0;
 	}
 
-	if (asprintf(&buf, TCB_DIR "/%s", user_name) == -1) {
+	buf = aprintf(TCB_DIR "/%s", user_name);
+	if (buf == NULL) {
 		fprintf(stderr,
 		        _("%s: Can't allocate memory, tcb entry for %s not removed.\n"),
 		        Prog, user_name);
@@ -1058,7 +1061,7 @@ int main (int argc, char **argv)
 		user_gid = pwd->pw_gid;
 
 		if (prefix[0]) {
-			xasprintf(&user_home, "%s/%s", prefix, pwd->pw_dir);
+			user_home = xaprintf("%s/%s", prefix, pwd->pw_dir);
 		} else {
 			user_home = xstrdup(pwd->pw_dir);
 		}
