@@ -42,7 +42,6 @@
 #include "faillog.h"
 #include "getdef.h"
 #include "groupio.h"
-#include "must_be.h"
 #include "nscd.h"
 #include "prototypes.h"
 #include "pwauth.h"
@@ -63,10 +62,12 @@
 #include "shadowlog.h"
 #include "sssd.h"
 #include "string/memset/memzero.h"
-#include "string/sprintf/xasprintf.h"
+#include "string/sprintf/xaprintf.h"
 #include "string/strcmp/streq.h"
+#include "string/strcmp/strprefix.h"
 #include "string/strdup/xstrdup.h"
 #include "time/day_to_str.h"
+#include "typetraits.h"
 
 
 /*
@@ -93,7 +94,7 @@
 #define E_SUB_GID_UPDATE 18	/* can't update the subordinate gid file */
 #endif				/* ENABLE_SUBIDS */
 
-#define	VALID(s)	(strcspn (s, ":\n") == strlen (s))
+#define VALID(s)  (!strpbrk(s, ":\n"))
 
 /*
  * Global variables
@@ -427,16 +428,13 @@ usage (int status)
 static char *new_pw_passwd (char *pw_pass)
 {
 	if (Lflg && ('!' != pw_pass[0])) {
-		char  *buf;
-
 #ifdef WITH_AUDIT
 		audit_logger (AUDIT_USER_CHAUTHTOK, Prog,
 		              "updating-passwd", user_newname, user_newid, 1);
 #endif
 		SYSLOG ((LOG_INFO, "lock user '%s' password", user_newname));
-		xasprintf(&buf, "!%s", pw_pass);
-		pw_pass = buf;
-	} else if (Uflg && pw_pass[0] == '!') {
+		pw_pass = xaprintf("!%s", pw_pass);
+	} else if (Uflg && strprefix(pw_pass, "!")) {
 		if (pw_pass[1] == '\0') {
 			fprintf (stderr,
 			         _("%s: unlocking the user's password would result in a passwordless account.\n"
@@ -1176,6 +1174,7 @@ process_flags(int argc, char **argv)
 				if (!streq(optarg, "")
 				     && '*'  != optarg[0]
 				     && !streq(optarg, "/sbin/nologin")
+				     && !streq(optarg, "/usr/sbin/nologin")
 				     && (   stat(optarg, &st) != 0
 				         || S_ISDIR(st.st_mode)
 				         || access(optarg, X_OK) != 0)) {
@@ -1302,10 +1301,10 @@ process_flags(int argc, char **argv)
 		user_newgid = user_gid;
 	}
 	if (prefix[0]) {
-		xasprintf(&prefix_user_home, "%s/%s", prefix, user_home);
+		prefix_user_home = xaprintf("%s/%s", prefix, user_home);
 		if (user_newhome) {
-			xasprintf(&prefix_user_newhome, "%s/%s",
-			          prefix, user_newhome);
+			prefix_user_newhome = xaprintf("%s/%s",
+			                               prefix, user_newhome);
 		}
 	} else {
 		prefix_user_home = user_home;
@@ -2079,9 +2078,9 @@ static void move_mailbox (void)
 	 * between stat and chown).  --marekm
 	 */
 	if (prefix[0]) {
-		xasprintf(&mailfile, "%s/%s/%s", prefix, maildir, user_name);
+		mailfile = xaprintf("%s/%s/%s", prefix, maildir, user_name);
 	} else {
-		xasprintf(&mailfile, "%s/%s", maildir, user_name);
+		mailfile = xaprintf("%s/%s", maildir, user_name);
 	}
 
 	fd = open (mailfile, O_RDONLY | O_NONBLOCK, 0);
@@ -2126,10 +2125,10 @@ static void move_mailbox (void)
 		char  *newmailfile;
 
 		if (prefix[0]) {
-			xasprintf(&newmailfile, "%s/%s/%s",
-			          prefix, maildir, user_newname);
+			newmailfile = xaprintf("%s/%s/%s",
+			                       prefix, maildir, user_newname);
 		} else {
-			xasprintf(&newmailfile, "%s/%s", maildir, user_newname);
+			newmailfile = xaprintf("%s/%s", maildir, user_newname);
 		}
 		if (   (link (mailfile, newmailfile) != 0)
 		    || (unlink (mailfile) != 0)) {
