@@ -18,9 +18,11 @@ def test_groupdel__delete_group(shadow: Shadow):
         1. Create group
         2. Delete group
     :steps:
-        1. Group doesn't exist
+        1. Check group entry
+        2. Check gshadow entry
     :expectedresults:
-        1. Group is not found
+        1. group entry for the user doesn't exist
+        2. gshadow entry for the user doesn't exist
     :customerscenario: False
     """
     shadow.groupadd("tgroup")
@@ -28,3 +30,6 @@ def test_groupdel__delete_group(shadow: Shadow):
 
     result = shadow.tools.getent.group("tgroup")
     assert result is None, "Group should not be found"
+
+    result = shadow.tools.getent.gshadow("tgroup")
+    assert result is None, "Group should not be found"
